@@ -1,7 +1,7 @@
 /*
  *  callbacks.h
  *	part of galculator
- *  	(c) 2002-2006 Simon Floery (chimaira@users.sf.net)
+ *  	(c) 2002-2007 Simon Floery (chimaira@users.sf.net)
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -294,3 +294,13 @@ on_user_function_button_clicked (GtkToggleButton       *button,
 
 void user_function_list_selection_changed_cb (GtkTreeSelection *selection, 
 					gpointer data);
+
+void on_paper_mode_activate (GtkMenuItem     *menuitem,
+			gpointer         user_data);
+
+void on_paper_entry_activate (GtkWidget *activated_widget, 
+			gpointer user_data);
+			
+gboolean paper_tree_view_selection_changed_cb (GtkWidget *widget,
+                                            GdkEventButton *event,
+                                            gpointer user_data);
