@@ -1,7 +1,7 @@
 /*
  *  galculator.h - general definitions.
  *	part of galculator
- *  	(c) 2002-2004 Simon Floery (chimaira@users.sf.net)
+ *  	(c) 2002-2007 Simon Floery (chimaira@users.sf.net)
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -40,6 +40,8 @@
 #define PREFS_GLADE_FILE 		PACKAGE_GLADE_DIR "/prefs.glade"
 #define FONT_GLADE_FILE 		PACKAGE_GLADE_DIR "/font.glade"
 #define COLOR_GLADE_FILE 		PACKAGE_GLADE_DIR "/color.glade"
+#define CLASSIC_VIEW_GLADE_FILE		PACKAGE_GLADE_DIR "/classic_view.glade"
+#define PAPER_VIEW_GLADE_FILE		PACKAGE_GLADE_DIR "/paper_view.glade"
 #define DISPCTRL_RIGHT_GLADE_FILE	PACKAGE_GLADE_DIR "/dispctrl_right.glade"
 #define DISPCTRL_RIGHTV_GLADE_FILE	PACKAGE_GLADE_DIR "/dispctrl_right_vertical.glade"
 #define DISPCTRL_BOTTOM_GLADE_FILE	PACKAGE_GLADE_DIR "/dispctrl_bottom.glade"
@@ -100,6 +102,7 @@ enum {
 enum {
 	BASIC_MODE,
 	SCIENTIFIC_MODE,
+	PAPER_MODE,
 	NR_MODES
 };
 
@@ -158,8 +161,8 @@ typedef struct {
 } s_operation_map;
 
 typedef struct {
-	int			x;
-	int			y;
+	int		x;
+	int		y;
 } s_point;
 
 typedef struct {
