@@ -1,7 +1,7 @@
 /*
  *  general_functions.c - this and that.
  *	part of galculator
- *  	(c) 2002-2004 Simon Floery (chimaira@users.sf.net)
+ *  	(c) 2002-2007 Simon Floery (chimaira@users.sf.net)
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -20,8 +20,10 @@
 
 #include <stdio.h>
 #include <stdlib.h>
+#include <stdarg.h>
 #include <string.h>
 #include <math.h>
+#include <ctype.h>
 
 #include "galculator.h"
 #include "general_functions.h"
@@ -48,10 +50,17 @@ double error_unsupported_hyp (double dummy)
 	return dummy;
 }
 
-void error_message (char *message)
+void error_message (char *format_string, ...)
 {	
-	fprintf (stderr, "[%s] %s. %s\n", PROG_NAME, message, BUG_REPORT);
+	va_list ap;
+	
+	fprintf (stderr, "[%s] ", PROG_NAME);
+	va_start(ap, format_string);
+	vfprintf (stderr, format_string, ap);
+	va_end(ap);
+	fprintf (stderr, ". %s\n", BUG_REPORT);
 }
+	
 
 /* the last entered number is removed. it is impossible to remove the last operation:
  * this would be a quite difficult taks, as every possible computation is done asap.
@@ -60,7 +69,7 @@ void error_message (char *message)
 
 void clear ()
 {
-	display_result_set (CLEARED_DISPLAY);
+	display_result_set (CLEARED_DISPLAY, TRUE, 0.);
 	if (current_status.notation == CS_FORMULA) ui_formula_entry_set ("");
 }
 
@@ -71,7 +80,7 @@ void clear ()
 void backspace ()
 {
 	if (current_status.notation == CS_FORMULA) ui_formula_entry_backspace();
-	else display_result_backspace();
+	else display_result_backspace(current_status.number);
 }
 
 /* clear all: display ("0"), calc_tree ... */
@@ -124,7 +133,7 @@ double axtof (char *bin_string, int base, int nr_bits, gboolean is_signed)
 			return_value += (lower_bin_string[counter] - '0') * pow (base, strlen (lower_bin_string) - 1 - counter);
 		else if (lower_bin_string[counter] - 'a' < 10) \
 			return_value += (lower_bin_string[counter] - 'a' + 10) * pow (base, strlen (lower_bin_string) - 1 - counter);
-		else fprintf (stderr, _("[%s] failed to convert char %c in function \"axtof\". %s\n"), PROG_NAME, lower_bin_string[counter], lower_bin_string[counter], BUG_REPORT);
+		else fprintf (stderr, _("[%s] failed to convert char %c in function \"axtof\". %s\n"), PROG_NAME, lower_bin_string[counter], BUG_REPORT);
 	}
 	
 	g_free (lower_bin_string);
@@ -208,14 +217,14 @@ char *add_leading_zeros (char *string, int multiple)
  * preference dialog sets. these are handler for the big configuration struct.
  */
 
-void set_button_label (GladeXML *xml, char *button_name, void *new_label)
+void set_button_font (GladeXML *xml, char *button_name, void *new_label)
 {
 	GtkButton	*button;
 	char 		**string_var;
 	
 	string_var = new_label;	
 	button = (GtkButton *) glade_xml_get_widget (xml, button_name);
-	if (button) gtk_button_set_label (button, *string_var);	
+	if (button) gtk_font_button_set_font_name (GTK_FONT_BUTTON(button), *string_var);	
 }
 
 void set_checkbutton (GladeXML *xml, char *checkbutton_name, void *is_active)
@@ -254,38 +263,20 @@ void set_optmenu (GladeXML *xml, char *optmenu_name, void *index)
 }
 
 /*
- * The callback fills the given widget with a rectangle in its foreground color.
- */
-
-gboolean da_expose_event_cb(GtkWidget *widget, GdkEventExpose *event, gpointer data)
-{
-	gdk_draw_rectangle (widget->window, widget->style->fg_gc[0], TRUE, 0, 0,\
-		widget->parent->allocation.width, widget->parent->allocation.height);
-	return TRUE;
-}
-
-/*
- * assembling my own colored button. as gnomecolorpicker is in libgnomeui, i do
- * it myself. remove the current label widget in button and put there a 
- * gtkdrawingarea. the drawing is done in da_expose_event_cb. The color is
- * set via widget->style->"fgs"
+ *
  */
 
 void set_button_color (GladeXML *xml, char *button_name, void *color_string)
 {
-	GtkWidget	*da;
+	GtkWidget	*button;
 	char 		**string_var;
 	GdkColor	color;
 
 	/* dereference */
 	string_var = color_string;
 	gdk_color_parse (*string_var, &color);
-	
-	da = glade_xml_get_widget (xml, button_name);
-
-	gtk_widget_modify_fg (da, 0, &color);
-	
-	g_signal_connect (G_OBJECT (da), "expose_event", G_CALLBACK (da_expose_event_cb), NULL);
+	button = glade_xml_get_widget (xml, button_name);
+	if (button) gtk_color_button_set_color (GTK_COLOR_BUTTON(button), &color);
 }
 
 void set_stacksize (GladeXML *xml, char *name, void *stack_size)
@@ -313,10 +304,11 @@ void set_entry (GladeXML *xml, char *entry_name, void *entry_text)
 
 /*
  * convert given GdkColor to a string so that gdk_color_parse gives the 
- * same color again.
+ * same color again. Formerly called gdk_color_to_string but since version 2.12
+ * gdk features that function by itself.
  */
 
-char *gdk_color_to_string (GdkColor color)
+char *convert_gdk_color_to_string (GdkColor color)
 {
 	return g_strdup_printf ("#%04X%04X%04X", color.red, color.green, color.blue);
 }
@@ -328,27 +320,41 @@ char *gdk_color_to_string (GdkColor color)
 void apply_preferences (s_preferences prefs)
 {
 	GtkWidget	*menu_item;
-	char		*button_font;
 
-	display_update_tags ();
-	display_set_bkg_color (prefs.bkg_color);
-	
+	/* not view specific */
 	set_widget_visibility (main_window_xml, "menubar", prefs.show_menu);
 	menu_item = glade_xml_get_widget (main_window_xml, "show_menubar1");
 	gtk_check_menu_item_set_active ((GtkCheckMenuItem *) menu_item, prefs.show_menu);
 
-	if (prefs.mode == BASIC_MODE) menu_item = 
-		glade_xml_get_widget (main_window_xml, "basic_mode");
-	else if (prefs.mode == SCIENTIFIC_MODE) menu_item = 
-		glade_xml_get_widget (main_window_xml, "scientific_mode");
+	switch (prefs.mode) {
+	case BASIC_MODE:
+		menu_item = 
+			glade_xml_get_widget (main_window_xml, "basic_mode");
+		break;
+	case SCIENTIFIC_MODE:
+		menu_item = 
+			glade_xml_get_widget (main_window_xml, "scientific_mode");
+		break;
+	case PAPER_MODE:
+		menu_item = 
+			glade_xml_get_widget (main_window_xml, "paper_mode");
+		break;
+	default:
+		error_message ("Unknown mode %i in \"apply_preferences\"", prefs.mode);
+	}
 	gtk_menu_item_activate ((GtkMenuItem *) menu_item);
-
+	
+	/* view specific */
+/*	display_update_tags ();
+	display_set_bkg_color (prefs.bkg_color);
+	
 	set_all_buttons_size (prefs.button_width, prefs.button_height);
 
 	if (prefs.custom_button_font == TRUE) button_font = g_strdup (prefs.button_font);
 	else button_font = g_strdup ("");
 	set_all_buttons_font (button_font);
 	g_free (button_font);
+*/
 }
 
 /*
@@ -460,9 +466,9 @@ void gfunc_f1 (GtkToggleButton *button)
 		on_operation_button_clicked (button, NULL);
 	else {
 		display_result_set_double (rpn_stack_swapxy(
-			display_result_get_double()));
+			display_result_get_double(current_status.number)), current_status.number);
 		stack = rpn_stack_get (RPN_FINITE_STACK);
-		display_stack_set_yzt_double (stack);
+		display_stack_set_yzt_double (stack, current_status.number);
 		free (stack);
 		current_status.rpn_stack_lift_enabled = TRUE;
 		current_status.calc_entry_start_new = TRUE;
@@ -480,9 +486,9 @@ void gfunc_f2 (GtkToggleButton *button)
 		on_operation_button_clicked (button, NULL);
 	else {
 		display_result_set_double (rpn_stack_rolldown(
-			display_result_get_double()));
+			display_result_get_double(current_status.number)), current_status.number);
 				stack = rpn_stack_get (RPN_FINITE_STACK);
-		display_stack_set_yzt_double (stack);
+		display_stack_set_yzt_double (stack, current_status.number);
 		free (stack);
 		current_status.rpn_stack_lift_enabled = TRUE;
 		current_status.calc_entry_start_new = TRUE;
@@ -503,9 +509,9 @@ void rpn_stack_lift ()
 	
 	if ((current_status.notation == CS_RPN) && 
 		(current_status.rpn_stack_lift_enabled == TRUE)) {
-		rpn_stack_push (display_result_get_double ());
+		rpn_stack_push (display_result_get_double (current_status.number));
 		stack = rpn_stack_get (RPN_FINITE_STACK);
-		display_stack_set_yzt_double (stack);
+		display_stack_set_yzt_double (stack, current_status.number);
 		free (stack);
 		current_status.rpn_stack_lift_enabled = FALSE;
 	}
@@ -516,7 +522,7 @@ void remember_display_values()
 	char 	*stack[3];
 	
 	if (prefs.rem_display == TRUE) {
-		display_result_set (prefs.rem_valuex);
+		display_result_set (prefs.rem_valuex, TRUE, string2double(prefs.rem_valuex, current_status.number));
 		/* for the result setting the display string is enough */
 		if (current_status.notation == CS_RPN) {
 			stack[0] = prefs.rem_valuey;
@@ -579,21 +585,20 @@ double string2double (char *string, int number_base)
 
 char *string_add_separator (char* string, gboolean separate, int block_length, char separator, char dpoint)
 {
-	int	int_length=0, frac_length=0, counter=0, new_counter=0, offset;
+	int		int_length=0, frac_length=0, counter=0, new_counter=0, offset;
 	char 	*new_string;
 	
-	
 	if (!separate) return g_strdup(string);
 	/* at first, get length of parts pre- and succeeding the decimal point */
-	while ((string[int_length] != '\0') && (string[int_length] != dpoint))
+	while ((string[int_length] != '\0') && (string[int_length] != dpoint) && (string[int_length] != 'e'))
 		int_length++;
-	if (string[int_length] != '\0')
-		while (string[int_length + frac_length + 1] != '\0') frac_length++;
+	if (string[int_length] == dpoint)
+		while ((string[int_length + frac_length + 1] != '\0') && (string[int_length + frac_length + 1] != 'e')) frac_length++;
 	/* then allocate memory for new string holding separators */
 	new_string = (char *) malloc ((strlen(string) + (int_length-1)/block_length +
 		(frac_length-1)/block_length + 1) * sizeof(char));
 	/* then copy from string to new_string and insert separators */
-	while ((string[counter] != '\0') && (string[counter] != dpoint)) {
+	while ((string[counter] != '\0') && (string[counter] != dpoint) && (string[counter] != 'e')) {
 		/* > ( == ) is horrible, yes, but somehow cool. avoids space
 		 * between sign char '-' and leading digit
 		 */
@@ -605,13 +610,13 @@ char *string_add_separator (char* string, gboolean separate, int block_length, c
 		new_counter++;
 		counter++;
 	}
-	if (string[int_length] != '\0') {
+	if ((string[int_length] != '\0')  && (string[int_length] != 'e')) {
 		/* copy decimal point */
 		new_string[new_counter] = string[counter];
 		new_counter++;
 		counter++;
 		offset = counter;
-		while (string[counter] != '\0') {
+		while ((string[counter] != '\0')  && (string[counter] != 'e')) {
 			if (((counter - offset) > 0) && ((counter - offset) % block_length == 0)) {
 				new_string[new_counter] = separator;
 				new_counter++;
@@ -621,7 +626,9 @@ char *string_add_separator (char* string, gboolean separate, int block_length, c
 			counter++;
 		}
 	}
+	while (string[counter] != '\0') new_string[new_counter++] = string[counter++];
 	new_string[new_counter] = '\0';
+	
 	return new_string;
 }
 
@@ -801,7 +808,8 @@ void prefs_sep_char_changed (GtkEditable *editable, char *prefs_sep, int number_
 	if (strlen(sep) > 0) {
 		if ((is_valid_number(number_base, *sep)) ||
 			((number_base == CS_DEC) && ((*sep == '-') ||
-			(*sep == 'e') || (*sep == dec_point[0]))))
+			(*sep == 'e') || (*sep == dec_point[0]))) ||
+			!isascii(*sep))
 			gtk_editable_delete_text (editable, 0, -1);
 		else {
 			result = display_result_get();
@@ -809,7 +817,7 @@ void prefs_sep_char_changed (GtkEditable *editable, char *prefs_sep, int number_
 			if (prefs_sep) g_free (prefs_sep);
 			prefs_sep = g_strdup(sep);
 			if (number_base == current_status.number) {
-				display_result_set(result);
+				display_result_set(result, FALSE, -1.);
 				display_stack_set_yzt(stack);
 			}
 			g_free (result);
@@ -818,3 +826,38 @@ void prefs_sep_char_changed (GtkEditable *editable, char *prefs_sep, int number_
 	}
 	g_free (sep);	
 }
+
+/*
+ * change_option - changes CURRENT_STATUS (!) and updates the display in classic
+ * view. The last but one function in the signal handling cascade of changing 
+ * base etc.
+ */
+
+void change_option (int new_status, int opt_group)
+{
+	int	old_status;
+	
+	switch (opt_group) {
+		case DISPLAY_OPT_NUMBER:
+			old_status = current_status.number;
+			if (old_status == new_status) return;
+			current_status.number = new_status;
+			if (prefs.mode != PAPER_MODE) display_change_option (old_status, new_status, DISPLAY_OPT_NUMBER);
+			break;
+		case DISPLAY_OPT_ANGLE:
+			old_status = current_status.angle;
+			if (old_status == new_status) return;
+			current_status.angle = new_status;
+			if (prefs.mode != PAPER_MODE) display_change_option (old_status, new_status, DISPLAY_OPT_ANGLE);
+			break;
+		case DISPLAY_OPT_NOTATION:
+			old_status = current_status.notation;
+			if (old_status == new_status) return;
+			current_status.notation = new_status;
+			if (prefs.mode != PAPER_MODE) display_change_option (old_status, new_status, DISPLAY_OPT_NOTATION);
+			break;
+		default:
+			error_message (_("unknown display option in function \"change_option\""));
+	}
+	current_status.calc_entry_start_new = TRUE;
+}
